@@ -1,10 +1,9 @@
 use crate::{
     connections::{Connection, ConnectionSide, Connections},
-    protocols::{ProtocolHandler, Protocols, ReturnableConnection, ReturnableItem},
+    protocols::Protocols,
     Config, KnownPeers, Stats,
 };
 
-use bytes::Bytes;
 use parking_lot::Mutex;
 use tokio::{
     net::{TcpListener, TcpStream},
@@ -29,7 +28,7 @@ macro_rules! enable_protocol {
         if let Some(handler) = $node.protocols.$handler_type.get() {
             let (conn_returner, conn_retriever) = oneshot::channel();
 
-            handler.send(($conn, conn_returner)).await;
+            handler.trigger(($conn, conn_returner)).await;
 
             match conn_retriever.await {
                 Ok(Ok(conn)) => conn,
@@ -66,7 +65,7 @@ pub struct InnerNode {
     /// The node's listening address.
     listening_addr: Option<SocketAddr>,
     /// Contains objects used by the protocols implemented by the node.
-    protocols: Protocols,
+    pub(crate) protocols: Protocols,
     /// A list of connections that have not been finalized yet.
     connecting: Mutex<HashSet<SocketAddr>>,
     /// Contains objects related to the node's active connections.
@@ -310,7 +309,7 @@ impl Node {
             if self.is_connected(addr) {
                 let (sender, receiver) = oneshot::channel();
 
-                handler.send((addr, sender)).await;
+                handler.trigger((addr, sender)).await;
                 let _ = receiver.await; // can't really fail
             }
         }
@@ -325,6 +324,11 @@ impl Node {
                 task.abort();
             }
 
+            // drop the associated outbound message sender if Writing is enabled
+            if let Some(handler) = self.protocols.writing_handler.get() {
+                handler.senders.write().remove(&addr);
+            }
+
             // if the (owning) node was not the initiator of the connection, it doesn't know the listening address
             // of the associated peer, so the related stats are unreliable; the next connection initiated by the
             // peer could be bound to an entirely different port number
@@ -340,28 +344,6 @@ impl Node {
         conn.is_some()
     }
 
-    /// Sends the provided message to the specified `SocketAddr`, as long as the `Writing` protocol is enabled.
-    pub fn send_direct_message(&self, addr: SocketAddr, message: Bytes) -> io::Result<()> {
-        self.connections
-            .sender(addr)?
-            .try_send(message)
-            .map_err(|e| {
-                error!(parent: self.span(), "can't send a message to {}: {}", addr, e);
-                self.stats().register_failure();
-                io::ErrorKind::Other.into()
-            })
-    }
-
-    /// Broadcasts the provided message to all peers, as long as the `Writing` protocol is enabled.
-    pub fn send_broadcast(&self, message: Bytes) {
-        for (message_sender, addr) in self.connections.senders() {
-            let _ = message_sender.try_send(message.clone()).map_err(|e| {
-                error!(parent: self.span(), "can't send a message to {}: {}", addr, e);
-                self.stats().register_failure();
-            });
-        }
-    }
-
     /// Returns a list containing addresses of active connections.
     pub fn connected_addrs(&self) -> Vec<SocketAddr> {
         self.connections.addrs()
@@ -399,34 +381,6 @@ impl Node {
         }
     }
 
-    /// Sets up the handshake handler, as part of the `Handshaking` protocol.
-    pub fn set_handshake_handler(&self, handler: ProtocolHandler<ReturnableConnection>) {
-        if self.protocols.handshake_handler.set(handler).is_err() {
-            panic!("the handshake_handler field was set more than once!");
-        }
-    }
-
-    /// Sets up the reading handler, as part of enabling the `Reading` protocol.
-    pub fn set_reading_handler(&self, handler: ProtocolHandler<ReturnableConnection>) {
-        if self.protocols.reading_handler.set(handler).is_err() {
-            panic!("the reading_handler field was set more than once!");
-        }
-    }
-
-    /// Sets up the writing handler, as part of enabling the `Writing` protocol.
-    pub fn set_writing_handler(&self, handler: ProtocolHandler<ReturnableConnection>) {
-        if self.protocols.writing_handler.set(handler).is_err() {
-            panic!("the writing_handler field was set more than once!");
-        }
-    }
-
-    /// Sets up the disconnect handler, as part of enabling the `Disconnect` protocol.
-    pub fn set_disconnect_handler(&self, handler: ProtocolHandler<ReturnableItem<SocketAddr, ()>>) {
-        if self.protocols.disconnect_handler.set(handler).is_err() {
-            panic!("the disconnect_handler field was set more than once!");
-        }
-    }
-
     /// Gracefully shuts the node down.
     pub async fn shut_down(&self) {
         debug!(parent: self.span(), "shutting down");
