@@ -1,7 +1,6 @@
 use crate::Pea2Pea;
 
-use fxhash::FxHashSet;
-use std::io;
+use std::{collections::HashSet, io};
 
 /// The way in which nodes are connected to each other; used in `connect_nodes`.
 #[derive(Debug, Clone, Copy, PartialEq, Eq)]
@@ -36,8 +35,7 @@ pub async fn connect_nodes<T: Pea2Pea>(nodes: &[T], topology: Topology) -> io::R
             }
         }
         Topology::Mesh => {
-            let mut connected_pairs =
-                FxHashSet::with_capacity_and_hasher((count - 1) * 2, Default::default());
+            let mut connected_pairs = HashSet::with_capacity((count - 1) * 2);
             for i in 0..count {
                 for (j, peer) in nodes.iter().enumerate() {
                     if i != j && connected_pairs.insert((i, j)) && connected_pairs.insert((j, i)) {
